aboutsummaryrefslogtreecommitdiffstats
path: root/include/llvm/Type.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/llvm/Type.h')
-rw-r--r--include/llvm/Type.h78
1 files changed, 44 insertions, 34 deletions
diff --git a/include/llvm/Type.h b/include/llvm/Type.h
index bc319c6..d09913a 100644
--- a/include/llvm/Type.h
+++ b/include/llvm/Type.h
@@ -82,13 +82,14 @@ public:
IntegerTyID, ///< 8: Arbitrary bit width integers
FunctionTyID, ///< 9: Functions
StructTyID, ///< 10: Structures
- ArrayTyID, ///< 11: Arrays
- PointerTyID, ///< 12: Pointers
- OpaqueTyID, ///< 13: Opaque: type with unknown structure
- VectorTyID, ///< 14: SIMD 'packed' format, or other vector type
+ UnionTyID, ///< 11: Unions
+ ArrayTyID, ///< 12: Arrays
+ PointerTyID, ///< 13: Pointers
+ OpaqueTyID, ///< 14: Opaque: type with unknown structure
+ VectorTyID, ///< 15: SIMD 'packed' format, or other vector type
NumTypeIDs, // Must remain as last defined ID
- LastPrimitiveTyID = LabelTyID,
+ LastPrimitiveTyID = MetadataTyID,
FirstDerivedTyID = IntegerTyID
};
@@ -181,6 +182,9 @@ public:
// are defined in private classes defined in Type.cpp for primitive types.
//
+ /// getDescription - Return the string representation of the type.
+ std::string getDescription() const;
+
/// getTypeID - Return the type id for the type. This will return one
/// of the TypeID enum elements defined above.
///
@@ -204,55 +208,60 @@ public:
/// isPPC_FP128Ty - Return true if this is powerpc long double.
bool isPPC_FP128Ty() const { return ID == PPC_FP128TyID; }
+ /// isFloatingPointTy - Return true if this is one of the five floating point
+ /// types
+ bool isFloatingPointTy() const { return ID == FloatTyID || ID == DoubleTyID ||
+ ID == X86_FP80TyID || ID == FP128TyID || ID == PPC_FP128TyID; }
+
+ /// isFPOrFPVectorTy - Return true if this is a FP type or a vector of FP.
+ ///
+ bool isFPOrFPVectorTy() const;
+
/// isLabelTy - Return true if this is 'label'.
bool isLabelTy() const { return ID == LabelTyID; }
/// isMetadataTy - Return true if this is 'metadata'.
bool isMetadataTy() const { return ID == MetadataTyID; }
- /// getDescription - Return the string representation of the type.
- std::string getDescription() const;
-
- /// isInteger - True if this is an instance of IntegerType.
+ /// isIntegerTy - True if this is an instance of IntegerType.
///
- bool isInteger() const { return ID == IntegerTyID; }
+ bool isIntegerTy() const { return ID == IntegerTyID; }
- /// isInteger - Return true if this is an IntegerType of the specified width.
- bool isInteger(unsigned Bitwidth) const;
+ /// isIntegerTy - Return true if this is an IntegerType of the given width.
+ bool isIntegerTy(unsigned Bitwidth) const;
- /// isIntOrIntVector - Return true if this is an integer type or a vector of
+ /// isIntOrIntVectorTy - Return true if this is an integer type or a vector of
/// integer types.
///
- bool isIntOrIntVector() const;
+ bool isIntOrIntVectorTy() const;
- /// isFloatingPoint - Return true if this is one of the five floating point
- /// types
- bool isFloatingPoint() const { return ID == FloatTyID || ID == DoubleTyID ||
- ID == X86_FP80TyID || ID == FP128TyID || ID == PPC_FP128TyID; }
+ /// isFunctionTy - True if this is an instance of FunctionType.
+ ///
+ bool isFunctionTy() const { return ID == FunctionTyID; }
- /// isFPOrFPVector - Return true if this is a FP type or a vector of FP types.
+ /// isStructTy - True if this is an instance of StructType.
///
- bool isFPOrFPVector() const;
-
- /// isFunction - True if this is an instance of FunctionType.
+ bool isStructTy() const { return ID == StructTyID; }
+
+ /// isUnionTy - True if this is an instance of UnionType.
///
- bool isFunction() const { return ID == FunctionTyID; }
+ bool isUnionTy() const { return ID == UnionTyID; }
- /// isStruct - True if this is an instance of StructType.
+ /// isArrayTy - True if this is an instance of ArrayType.
///
- bool isStruct() const { return ID == StructTyID; }
+ bool isArrayTy() const { return ID == ArrayTyID; }
- /// isArray - True if this is an instance of ArrayType.
+ /// isPointerTy - True if this is an instance of PointerType.
///
- bool isArray() const { return ID == ArrayTyID; }
+ bool isPointerTy() const { return ID == PointerTyID; }
- /// isPointer - True if this is an instance of PointerType.
+ /// isOpaqueTy - True if this is an instance of OpaqueType.
///
- bool isPointer() const { return ID == PointerTyID; }
+ bool isOpaqueTy() const { return ID == OpaqueTyID; }
- /// isVector - True if this is an instance of VectorType.
+ /// isVectorTy - True if this is an instance of VectorType.
///
- bool isVector() const { return ID == VectorTyID; }
+ bool isVectorTy() const { return ID == VectorTyID; }
/// isAbstract - True if the type is either an Opaque type, or is a derived
/// type that includes an opaque type somewhere in it.
@@ -297,7 +306,7 @@ public:
/// does not include vector types.
///
inline bool isAggregateType() const {
- return ID == StructTyID || ID == ArrayTyID;
+ return ID == StructTyID || ID == ArrayTyID || ID == UnionTyID;
}
/// isSized - Return true if it makes sense to take the size of this type. To
@@ -306,11 +315,12 @@ public:
///
bool isSized() const {
// If it's a primitive, it is always sized.
- if (ID == IntegerTyID || isFloatingPoint() || ID == PointerTyID)
+ if (ID == IntegerTyID || isFloatingPointTy() || ID == PointerTyID)
return true;
// If it is not something that can have a size (e.g. a function or label),
// it doesn't have a size.
- if (ID != StructTyID && ID != ArrayTyID && ID != VectorTyID)
+ if (ID != StructTyID && ID != ArrayTyID && ID != VectorTyID &&
+ ID != UnionTyID)
return false;
// If it is something that can have a size and it's concrete, it definitely
// has a size, otherwise we have to try harder to decide.